DeepAdxLogLevel enum
SDK 日志级别。
与 Android DeepAdxLogLevel 数值对齐(0/1/2/3/10/-1),
iOS 侧映射为 DeepAdxLogLevel(0 不打印 … 5 全部打印)。
Values
- none → const DeepAdxLogLevel
-
不打印任何日志
const DeepAdxLogLevel(0) - defaultLevel → const DeepAdxLogLevel
-
默认等级,打印 SDK 核心方法日志
const DeepAdxLogLevel(1) - simple → const DeepAdxLogLevel
-
基础等级,方便普通接入者查看接入效果
const DeepAdxLogLevel(2) - high → const DeepAdxLogLevel
-
高级模式,打印辅助判断的执行信息
const DeepAdxLogLevel(3) - max → const DeepAdxLogLevel
-
最大等级,打印全部信息
const DeepAdxLogLevel(10) - custom → const DeepAdxLogLevel
-
自定义级别
const DeepAdxLogLevel(-1)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
对应原生数值
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int? value) → DeepAdxLogLevel - 从数值解析日志级别;未匹配时返回 defaultLevel。
Constants
-
values
→ const List<
DeepAdxLogLevel> - A constant List of the values in this enum, in order of their declaration.